Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterAuthServiceServer(s grpc.ServiceRegistrar, srv AuthServiceServer)
- type AuthServiceClient
- type AuthServiceServer
- type CreateManagementKeyRequest
- func (*CreateManagementKeyRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CreateManagementKeyRequest) GetManagementKey() *ManagementKey
- func (*CreateManagementKeyRequest) ProtoMessage()
- func (x *CreateManagementKeyRequest) ProtoReflect() protoreflect.Message
- func (x *CreateManagementKeyRequest) Reset()
- func (x *CreateManagementKeyRequest) String() string
- type CreateManagementKeyResponse
- func (*CreateManagementKeyResponse) Descriptor() ([]byte, []int)deprecated
- func (x *CreateManagementKeyResponse) GetManagementKey() *ManagementKey
- func (*CreateManagementKeyResponse) ProtoMessage()
- func (x *CreateManagementKeyResponse) ProtoReflect() protoreflect.Message
- func (x *CreateManagementKeyResponse) Reset()
- func (x *CreateManagementKeyResponse) String() string
- type DeleteManagementKeyRequest
- func (*DeleteManagementKeyRequest) Descriptor() ([]byte, []int)deprecated
- func (x *DeleteManagementKeyRequest) GetAccountId() string
- func (x *DeleteManagementKeyRequest) GetManagementKeyId() string
- func (*DeleteManagementKeyRequest) ProtoMessage()
- func (x *DeleteManagementKeyRequest) ProtoReflect() protoreflect.Message
- func (x *DeleteManagementKeyRequest) Reset()
- func (x *DeleteManagementKeyRequest) String() string
- type DeleteManagementKeyResponse
- type ListManagementKeysRequest
- func (*ListManagementKeysRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ListManagementKeysRequest) GetAccountId() string
- func (*ListManagementKeysRequest) ProtoMessage()
- func (x *ListManagementKeysRequest) ProtoReflect() protoreflect.Message
- func (x *ListManagementKeysRequest) Reset()
- func (x *ListManagementKeysRequest) String() string
- type ListManagementKeysResponse
- func (*ListManagementKeysResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ListManagementKeysResponse) GetItems() []*ManagementKey
- func (*ListManagementKeysResponse) ProtoMessage()
- func (x *ListManagementKeysResponse) ProtoReflect() protoreflect.Message
- func (x *ListManagementKeysResponse) Reset()
- func (x *ListManagementKeysResponse) String() string
- type ManagementKey
- func (*ManagementKey) Descriptor() ([]byte, []int)deprecated
- func (x *ManagementKey) GetAccountId() string
- func (x *ManagementKey) GetCreatedAt() *timestamppb.Timestamp
- func (x *ManagementKey) GetId() string
- func (x *ManagementKey) GetKey() string
- func (x *ManagementKey) GetPrefix() string
- func (*ManagementKey) ProtoMessage()
- func (x *ManagementKey) ProtoReflect() protoreflect.Message
- func (x *ManagementKey) Reset()
- func (x *ManagementKey) String() string
- type UnimplementedAuthServiceServer
- func (UnimplementedAuthServiceServer) CreateManagementKey(context.Context, *CreateManagementKeyRequest) (*CreateManagementKeyResponse, error)
- func (UnimplementedAuthServiceServer) DeleteManagementKey(context.Context, *DeleteManagementKeyRequest) (*DeleteManagementKeyResponse, error)
- func (UnimplementedAuthServiceServer) ListManagementKeys(context.Context, *ListManagementKeysRequest) (*ListManagementKeysResponse, error)
- type UnsafeAuthServiceServer
Constants ¶
const ( AuthService_ListManagementKeys_FullMethodName = "/qdrant.cloud.auth.v1.AuthService/ListManagementKeys" AuthService_CreateManagementKey_FullMethodName = "/qdrant.cloud.auth.v1.AuthService/CreateManagementKey" AuthService_DeleteManagementKey_FullMethodName = "/qdrant.cloud.auth.v1.AuthService/DeleteManagementKey" )
Variables ¶
var AuthService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "qdrant.cloud.auth.v1.AuthService", HandlerType: (*AuthServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "ListManagementKeys", Handler: _AuthService_ListManagementKeys_Handler, }, { MethodName: "CreateManagementKey", Handler: _AuthService_CreateManagementKey_Handler, }, { MethodName: "DeleteManagementKey", Handler: _AuthService_DeleteManagementKey_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "qdrant/cloud/auth/v1/auth.proto", }
AuthService_ServiceDesc is the grpc.ServiceDesc for AuthService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
var File_qdrant_cloud_auth_v1_auth_proto protoreflect.FileDescriptor
Functions ¶
func RegisterAuthServiceServer ¶
func RegisterAuthServiceServer(s grpc.ServiceRegistrar, srv AuthServiceServer)
Types ¶
type AuthServiceClient ¶
type AuthServiceClient interface {
// Lists all management keys in the account identified by the given ID.
// Required permissions:
// - read:management_keys
ListManagementKeys(ctx context.Context, in *ListManagementKeysRequest, opts ...grpc.CallOption) (*ListManagementKeysResponse, error)
// Creates a management key in the account identified by the given ID.
// Required permissions:
// - write:management_keys
CreateManagementKey(ctx context.Context, in *CreateManagementKeyRequest, opts ...grpc.CallOption) (*CreateManagementKeyResponse, error)
// Deletes a management key in the account identified by the given ID.
// Required permissions:
// - delete:management_keys
DeleteManagementKey(ctx context.Context, in *DeleteManagementKeyRequest, opts ...grpc.CallOption) (*DeleteManagementKeyResponse, error)
}
AuthServiceClient is the client API for AuthService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
AuthService is the API used to manage the authentication settings (like management keys) for Qdrant Cloud.
func NewAuthServiceClient ¶
func NewAuthServiceClient(cc grpc.ClientConnInterface) AuthServiceClient
type AuthServiceServer ¶
type AuthServiceServer interface {
// Lists all management keys in the account identified by the given ID.
// Required permissions:
// - read:management_keys
ListManagementKeys(context.Context, *ListManagementKeysRequest) (*ListManagementKeysResponse, error)
// Creates a management key in the account identified by the given ID.
// Required permissions:
// - write:management_keys
CreateManagementKey(context.Context, *CreateManagementKeyRequest) (*CreateManagementKeyResponse, error)
// Deletes a management key in the account identified by the given ID.
// Required permissions:
// - delete:management_keys
DeleteManagementKey(context.Context, *DeleteManagementKeyRequest) (*DeleteManagementKeyResponse, error)
// contains filtered or unexported methods
}
AuthServiceServer is the server API for AuthService service. All implementations must embed UnimplementedAuthServiceServer for forward compatibility.
AuthService is the API used to manage the authentication settings (like management keys) for Qdrant Cloud.
type CreateManagementKeyRequest ¶
type CreateManagementKeyRequest struct {
// The actual management key.
ManagementKey *ManagementKey `protobuf:"bytes,1,opt,name=management_key,json=managementKey,proto3" json:"management_key,omitempty"`
// contains filtered or unexported fields
}
CreateManagementKeyRequest is the request for the CreateManagementKey function
func (*CreateManagementKeyRequest) Descriptor
deprecated
func (*CreateManagementKeyRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateManagementKeyRequest.ProtoReflect.Descriptor instead.
func (*CreateManagementKeyRequest) GetManagementKey ¶
func (x *CreateManagementKeyRequest) GetManagementKey() *ManagementKey
func (*CreateManagementKeyRequest) ProtoMessage ¶
func (*CreateManagementKeyRequest) ProtoMessage()
func (*CreateManagementKeyRequest) ProtoReflect ¶
func (x *CreateManagementKeyRequest) ProtoReflect() protoreflect.Message
func (*CreateManagementKeyRequest) Reset ¶
func (x *CreateManagementKeyRequest) Reset()
func (*CreateManagementKeyRequest) String ¶
func (x *CreateManagementKeyRequest) String() string
type CreateManagementKeyResponse ¶
type CreateManagementKeyResponse struct {
// The actual management key.
ManagementKey *ManagementKey `protobuf:"bytes,1,opt,name=management_key,json=managementKey,proto3" json:"management_key,omitempty"`
// contains filtered or unexported fields
}
CreateManagementKeyResponse is the response from the CreateManagementKey function
func (*CreateManagementKeyResponse) Descriptor
deprecated
func (*CreateManagementKeyResponse) Descriptor() ([]byte, []int)
Deprecated: Use CreateManagementKeyResponse.ProtoReflect.Descriptor instead.
func (*CreateManagementKeyResponse) GetManagementKey ¶
func (x *CreateManagementKeyResponse) GetManagementKey() *ManagementKey
func (*CreateManagementKeyResponse) ProtoMessage ¶
func (*CreateManagementKeyResponse) ProtoMessage()
func (*CreateManagementKeyResponse) ProtoReflect ¶
func (x *CreateManagementKeyResponse) ProtoReflect() protoreflect.Message
func (*CreateManagementKeyResponse) Reset ¶
func (x *CreateManagementKeyResponse) Reset()
func (*CreateManagementKeyResponse) String ¶
func (x *CreateManagementKeyResponse) String() string
type DeleteManagementKeyRequest ¶
type DeleteManagementKeyRequest struct {
// The identifier of the account (in GUID format).
// This is a required field.
AccountId string `protobuf:"bytes,1,opt,name=account_id,json=accountId,proto3" json:"account_id,omitempty"`
// The identifier of the management key (in GUID format).
// This is a required field.
ManagementKeyId string `protobuf:"bytes,2,opt,name=management_key_id,json=managementKeyId,proto3" json:"management_key_id,omitempty"`
// contains filtered or unexported fields
}
DeleteManagementKeyRequest is the request for the DeleteManagementKey function
func (*DeleteManagementKeyRequest) Descriptor
deprecated
func (*DeleteManagementKeyRequest) Descriptor() ([]byte, []int)
Deprecated: Use DeleteManagementKeyRequest.ProtoReflect.Descriptor instead.
func (*DeleteManagementKeyRequest) GetAccountId ¶
func (x *DeleteManagementKeyRequest) GetAccountId() string
func (*DeleteManagementKeyRequest) GetManagementKeyId ¶
func (x *DeleteManagementKeyRequest) GetManagementKeyId() string
func (*DeleteManagementKeyRequest) ProtoMessage ¶
func (*DeleteManagementKeyRequest) ProtoMessage()
func (*DeleteManagementKeyRequest) ProtoReflect ¶
func (x *DeleteManagementKeyRequest) ProtoReflect() protoreflect.Message
func (*DeleteManagementKeyRequest) Reset ¶
func (x *DeleteManagementKeyRequest) Reset()
func (*DeleteManagementKeyRequest) String ¶
func (x *DeleteManagementKeyRequest) String() string
type DeleteManagementKeyResponse ¶
type DeleteManagementKeyResponse struct {
// contains filtered or unexported fields
}
DeleteManagementKeyResponse is the response from the DeleteManagementKey function
func (*DeleteManagementKeyResponse) Descriptor
deprecated
func (*DeleteManagementKeyResponse) Descriptor() ([]byte, []int)
Deprecated: Use DeleteManagementKeyResponse.ProtoReflect.Descriptor instead.
func (*DeleteManagementKeyResponse) ProtoMessage ¶
func (*DeleteManagementKeyResponse) ProtoMessage()
func (*DeleteManagementKeyResponse) ProtoReflect ¶
func (x *DeleteManagementKeyResponse) ProtoReflect() protoreflect.Message
func (*DeleteManagementKeyResponse) Reset ¶
func (x *DeleteManagementKeyResponse) Reset()
func (*DeleteManagementKeyResponse) String ¶
func (x *DeleteManagementKeyResponse) String() string
type ListManagementKeysRequest ¶
type ListManagementKeysRequest struct {
// The identifier of the account (in GUID format).
// This is a required field.
AccountId string `protobuf:"bytes,1,opt,name=account_id,json=accountId,proto3" json:"account_id,omitempty"`
// contains filtered or unexported fields
}
ListManagementKeysRequest is the request for the ListManagementKeys function
func (*ListManagementKeysRequest) Descriptor
deprecated
func (*ListManagementKeysRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListManagementKeysRequest.ProtoReflect.Descriptor instead.
func (*ListManagementKeysRequest) GetAccountId ¶
func (x *ListManagementKeysRequest) GetAccountId() string
func (*ListManagementKeysRequest) ProtoMessage ¶
func (*ListManagementKeysRequest) ProtoMessage()
func (*ListManagementKeysRequest) ProtoReflect ¶
func (x *ListManagementKeysRequest) ProtoReflect() protoreflect.Message
func (*ListManagementKeysRequest) Reset ¶
func (x *ListManagementKeysRequest) Reset()
func (*ListManagementKeysRequest) String ¶
func (x *ListManagementKeysRequest) String() string
type ListManagementKeysResponse ¶
type ListManagementKeysResponse struct {
// The actual management keys in this list.
Items []*ManagementKey `protobuf:"bytes,1,rep,name=items,proto3" json:"items,omitempty"`
// contains filtered or unexported fields
}
ListManagementKeysResponse is the response from the ListManagementKeys function
func (*ListManagementKeysResponse) Descriptor
deprecated
func (*ListManagementKeysResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListManagementKeysResponse.ProtoReflect.Descriptor instead.
func (*ListManagementKeysResponse) GetItems ¶
func (x *ListManagementKeysResponse) GetItems() []*ManagementKey
func (*ListManagementKeysResponse) ProtoMessage ¶
func (*ListManagementKeysResponse) ProtoMessage()
func (*ListManagementKeysResponse) ProtoReflect ¶
func (x *ListManagementKeysResponse) ProtoReflect() protoreflect.Message
func (*ListManagementKeysResponse) Reset ¶
func (x *ListManagementKeysResponse) Reset()
func (*ListManagementKeysResponse) String ¶
func (x *ListManagementKeysResponse) String() string
type ManagementKey ¶
type ManagementKey struct {
// Unique identifier for the management key (in GUID format).
// This is a read-only field and will be available after a management key is created.
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
// The identifier of the account (in GUID format).
// This is a required field.
AccountId string `protobuf:"bytes,2,opt,name=account_id,json=accountId,proto3" json:"account_id,omitempty"`
// Timestamp when the management key was created.
// This is a read-only field and will be available after a management key is created.
CreatedAt *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
// Prefix for the management key, this represents the first bytes of the key.
// This is a read-only field and will be available after a management key is created.
Prefix string `protobuf:"bytes,4,opt,name=prefix,proto3" json:"prefix,omitempty"`
// The value of the key, to be used to authenticate requests to the Qdrant Cloud API.
// This is a read-only field and will be available only once in the response of CreateManagementKey.
// You should securely store this key and it should be handled as a secret.
Key string `protobuf:"bytes,5,opt,name=key,proto3" json:"key,omitempty"`
// contains filtered or unexported fields
}
A ManagementKey represents a management key of a Qdrant Cloud account. This management key grants access to the Qdrant Cloud API.
func (*ManagementKey) Descriptor
deprecated
func (*ManagementKey) Descriptor() ([]byte, []int)
Deprecated: Use ManagementKey.ProtoReflect.Descriptor instead.
func (*ManagementKey) GetAccountId ¶
func (x *ManagementKey) GetAccountId() string
func (*ManagementKey) GetCreatedAt ¶
func (x *ManagementKey) GetCreatedAt() *timestamppb.Timestamp
func (*ManagementKey) GetId ¶
func (x *ManagementKey) GetId() string
func (*ManagementKey) GetKey ¶
func (x *ManagementKey) GetKey() string
func (*ManagementKey) GetPrefix ¶
func (x *ManagementKey) GetPrefix() string
func (*ManagementKey) ProtoMessage ¶
func (*ManagementKey) ProtoMessage()
func (*ManagementKey) ProtoReflect ¶
func (x *ManagementKey) ProtoReflect() protoreflect.Message
func (*ManagementKey) Reset ¶
func (x *ManagementKey) Reset()
func (*ManagementKey) String ¶
func (x *ManagementKey) String() string
type UnimplementedAuthServiceServer ¶
type UnimplementedAuthServiceServer struct{}
UnimplementedAuthServiceServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedAuthServiceServer) CreateManagementKey ¶
func (UnimplementedAuthServiceServer) CreateManagementKey(context.Context, *CreateManagementKeyRequest) (*CreateManagementKeyResponse, error)
func (UnimplementedAuthServiceServer) DeleteManagementKey ¶
func (UnimplementedAuthServiceServer) DeleteManagementKey(context.Context, *DeleteManagementKeyRequest) (*DeleteManagementKeyResponse, error)
func (UnimplementedAuthServiceServer) ListManagementKeys ¶
func (UnimplementedAuthServiceServer) ListManagementKeys(context.Context, *ListManagementKeysRequest) (*ListManagementKeysResponse, error)
type UnsafeAuthServiceServer ¶
type UnsafeAuthServiceServer interface {
// contains filtered or unexported methods
}
UnsafeAuthServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AuthServiceServer will result in compilation errors.